###############################################################################
##	Filename:	GlowFX.py
##	
##	Nano's Glow Effects Fixes for Light Flickers Version 1.0
##	
##	Created:	03/21/2003 - NanoByte a.k.a Michael T. Braams
###############################################################################

import App
import MissionLib
import Foundation
import Actions.EffectScriptActions
import Actions.ShipScriptActions

###############################################################################
## Initialize Glow Enhancement when Player Ship Loads...
###############################################################################
def CreateShipGlowFix(pcScript, pSet, pcIdentifier, pcLocationName, iWarpFlash = 0, bGrabPreloaded = 1, shipDef = None):

	# Creates a new ship



	# Check if a ship of this type has been pre-created for us.

	pShip = None

	if bGrabPreloaded:

		import MissionLib

		pMission = MissionLib.GetMission()

		if pMission:

			pShip = pMission.GetPrecreatedShip(pcScript)



	if not pShip:

		# FIX ME:  This is back-arsewards in that the ship script is gotten from kStats

		# which was gotten from the ship script in the first place.  But this is the

		# least intrusive fix I can think of

		hpPrefix = 'ships.Hardpoints.'

		sModule = "ships." + pcScript



		if shipDef and shipDef.hasattr('shipPrefix'):

			sModule = shipDef.shipPrefix + pcScript

			hpPrefix = shipDef.shipPrefix + 'Hardpoints.'



		pModule = __import__ (sModule)



		pModule.LoadModel ()

		kStats = pModule.GetShipStats ()



		pShip = App.ShipClass_Create( kStats['Name'] )

		pShip.SetScript(sModule)



		if (kStats.has_key('DamageRadMod')):

			pShip.SetVisibleDamageRadiusModifier( kStats['DamageRadMod'] )



		if (kStats.has_key('DamageStrMod')):

			pShip.SetVisibleDamageStrengthModifier( kStats['DamageStrMod'] )



		if (kStats.has_key('SpecularCoef')):

			pShip.SetSpecularKs( kStats['SpecularCoef'] )



		pPropertySet = pShip.GetPropertySet()

		# Load hardpoints.

		mod = __import__(hpPrefix + kStats['HardpointFile'])

		App.g_kModelPropertyManager.ClearLocalTemplates()

		reload(mod)

		mod.LoadPropertySet(pPropertySet)



		pShip.SetupProperties()

		pShip.SetNetType (kStats['Species'])



	if pSet:

		if not pSet.AddObjectToSet( pShip, pcIdentifier ):

#			debug("Unable to add ship %s to set %s" % (pcIdentifier, pSet.GetName()))



			# Delete the ship.

			pDeletionEvent = App.TGEvent_Create()

			pDeletionEvent.SetEventType(App.ET_DELETE_OBJECT_PUBLIC)

			pDeletionEvent.SetDestination(pShip)

			App.g_kEventManager.AddEvent(pDeletionEvent)



			return None



		# Place the object at the specified location.

		if pcLocationName:

			pShip.PlaceObjectByName( pcLocationName )



		pShip.UpdateNodeOnly()



		if (iWarpFlash != 0):

			pWarp = pShip.GetWarpEngineSubsystem()

			if (pWarp != None) and (pcLocationName != None) and (pcLocationName != ""):

				pSequence = Actions.EffectScriptActions.CreateEndWarpSequence(pShip.GetObjID(), pcLocationName)

				pSequence.Play()

			else:

				# Just create a warp flash wherever the thing appears.

				pAction = App.TGScriptAction_Create("Actions.EffectScriptActions", "WarpFlash", pShip.GetObjID())

				pSequence = App.TGSequence_Create()

				pSequence.AddAction(pAction)

				pSequence.Play()



	# The Foundation requires that added ships select a species number that corresponds to an icon.

	# As icons are loaded, they are issued numbers by the Foundation.  This makes sure that a ship

	# has the species number that corresponds to the icon. -Dasher42



	pShipProperty = pShip.GetShipProperty()



	if pShipProperty:

		if shipDef:

			pShipProperty.SetSpecies(shipDef.GetIconNum())

		elif Foundation.shipList._keyList.has_key(pcScript):

			pShipProperty.SetSpecies(Foundation.shipList[pcScript].GetIconNum())

	else:

		print 'ERROR:  Cannot get ship property for %s, check hardpoints!' % (pcScript)


	### Addition for Glow Fix ###
	NanoGlowFX(pShip)
	###


	return pShip


###############################################################################
## Fix Glows After ship Docks with StarBase...
###############################################################################
def RepairShipFullyGlowFix(pAction, iShipID):
	"Repairs a ship fully. Every subsystem is restored to full health."

	pShip = App.ShipClass_Cast(App.TGObject_GetTGObjectPtr(iShipID))

	if(pShip is None):
		return 0

	# Iterate over all the subsystems of the ship.
	pIterator = pShip.StartGetSubsystemMatch(App.CT_SHIP_SUBSYSTEM)
	pSubsystem = pShip.GetNextSubsystemMatch(pIterator)

	while (pSubsystem != None):
		Actions.ShipScriptActions.RepairSubsystemFully(pAction, pSubsystem.GetObjID())
		pSubsystem = pShip.GetNextSubsystemMatch(pIterator)

	pShip.EndGetSubsystemMatch(pIterator)

	# Set all of ship's shields to max.
	pShields = pShip.GetShields()

	if (pShields != None):
		for ShieldDir in range(App.ShieldClass.NUM_SHIELDS):
			pShields.SetCurShields(ShieldDir, pShields.GetMaxShields(ShieldDir))

	# Set the power of the ship to max.
	pPower = pShip.GetPowerSubsystem()
	if (pPower != None):
		pPower.SetMainBatteryPower(pPower.GetMainBatteryLimit())
		pPower.SetBackupBatteryPower(pPower.GetBackupBatteryLimit())
	
	pShip.RemoveVisibleDamage()

	# Replenish probe supply.
	pSensors = pShip.GetSensorSubsystem()
	if pSensors:
		pProp = pSensors.GetProperty()
		if pProp:
			pSensors.SetNumProbes(pProp.GetMaxProbes())

	### Addition for Glow Fix ###
	NanoGlowFX(pShip)
	###
	
	return(0)

###############################################################################
## Fix Glows After ship Docks with StarBase...
###############################################################################
def NanoGlowFX(pShip):
	
	if (App.g_kLODModelManager.AreGlowMapsEnabled() == 1):
		App.g_kLODModelManager.SetGlowMapsEnabled(0)
		App.g_kLODModelManager.SetGlowMapsEnabled(1)

###############################################################################
## End of Glow FX Fixes
###############################################################################